| Safe Haskell | None |
|---|---|
| Language | GHC2024 |
TestMnistCNNS
Description
Tests of MnistCnnShaped2 convolutional neural network using a few different optimization pipelines.
With the current CPU backend it's slow enough that it's hard to see if it trains.
| Safe Haskell | None |
|---|---|
| Language | GHC2024 |
TestMnistCNNS
Description
Tests of MnistCnnShaped2 convolutional neural network using a few different optimization pipelines.
With the current CPU backend it's slow enough that it's hard to see if it trains.